<?php

namespace App\Controller\Config;

use App\Entity\Machine;
use App\Form\Config\MachineEditForm;
use App\Misc\FlashType;
use App\Repository\MachineRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

/**
 * Controller for the configuration pages of machines
 */
#[Route('/Config/Machine')]
class MachineController extends AbstractController {
    private readonly EntityManagerInterface $entityManager;
    /**
     * @var MachineRepository The machine repository
     */
    private readonly MachineRepository $machineRepository;

    /**
     * Initialization
     *
     * @param EntityManagerInterface $entityManager     The entity manager
     * @param MachineRepository      $machineRepository The machine repository
     */
    public function __construct (EntityManagerInterface $entityManager, MachineRepository $machineRepository) {
        $this->entityManager = $entityManager;
        $this->machineRepository = $machineRepository;
    }

    /**
     * List of machines
     *
     * @return Response The response
     */
    #[Route('/', name: 'config_machine_list', alias: 'config_machine')]
    public function list (): Response {
        return $this->render(
            'Config/Machine/List.html.twig',
            [
                'machines' => $this->machineRepository->findAll(),
            ]
        );
    }

    /**
     * Edit/Create a machine
     *
     * @param Request      $request The request
     * @param Machine|null $machine The machine to edit
     *
     * @return Response The response
     */
    #[Route('/Create', name: 'config_machine_create')]
    #[Route('/Edit-{id}', name: 'config_machine_edit')]
    public function edit (Request $request, ?Machine $machine = null): Response {
        $machine ??= new Machine();

        $form = $this->createForm(MachineEditForm::class, $machine);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $this->entityManager->persist($machine);
            $this->entityManager->flush();

            $this->addFlash(FlashType::SUCCESS, 'La machine a bien été enregistré.');
            return $this->redirectToRoute('config_machine_list');
        }

        return $this->render('Config/Machine/Edit.html.twig', [
            'machine' => $machine,
            'form'    => $form->createView(),
        ]);
    }

    /**
     * Delete a machine
     *
     * @param Machine $machine The machine to delete
     *
     * @return Response The response
     */
    #[Route('/Delete-{id}', name: 'config_machine_delete')]
    public function delete (Machine $machine): Response {
        $this->entityManager->remove($machine);
        $this->entityManager->flush();

        $this->addFlash(FlashType::SUCCESS, 'La machine a bien été supprimé.');
        return $this->redirectToRoute('config_machine_list');
    }
}
