<?php

namespace App\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Implementation for an entity with a name
 */
trait TNamedEntity {
    /**
     * @var string|null The name
     */
    #[ORM\Column(length: 50, unique: true)]
    #[Assert\NotBlank(message: 'Veuillez saisir un nom')]
    #[Assert\Unique(message: 'Il existe déjà un élément avec ce nom')]
    private ?string $name = null;

    /**
     * The name
     *
     * @return string|null The name
     */
    public function getName (): ?string {
        return $this->name;
    }
    /**
     * Set the name
     *
     * @param string $name The name
     *
     * @return $this
     */
    public function setName (string $name): static {
        $this->name = $name;

        return $this;
    }

    /**
     * @inheritDoc
     */
    public function __toString (): string {
        return $this->getName();
    }
}