<?php

namespace App\Form\User;

use App\Entity\User;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\RepeatedType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\IsTrue;
use Symfony\Component\Validator\Constraints\Length;
use Symfony\Component\Validator\Constraints\NotBlank;

/**
 * The form for user registration (sign up)
 */
class SignUpFormType extends AbstractType {
    /**
     * @inheritDoc
     */
    public function configureOptions (OptionsResolver $resolver): void {
        $resolver->setDefaults(
            [
                'data_class' => User::class,
            ]
        );
    }

    /**
     * @inheritDoc
     */
    public function buildForm (FormBuilderInterface $builder, array $options): void {
        $builder
            ->add('email', null, [
                'label' => 'Email',
            ])
            ->add('name', null, [
                'label' => 'Nom',
            ])
            ->add('newPassword', RepeatedType::class, [
                'type'            => PasswordType::class,
                'mapped'          => false,
                'attr'            => ['autocomplete' => 'new-password'],
                'invalid_message' => 'Les mots de passe doivent correspondre.',
                'constraints'     => [
                    new NotBlank(
                        [
                            'message' => 'Le mot de passe est requis.',
                        ]
                    ),
                    new Length(
                        [
                            'min'        => 6,
                            'minMessage' => 'Le mot de passe doit faire au moins {{ limit }} caractères.',
                            'max'        => 4096,           // max length allowed by Symfony for security reasons
                        ]
                    ),
                ],
                'first_options'   => [
                    'label' => 'Mot de passe',
                ],
                'second_options'  => [
                    'label' => 'Confirmation du mot de passe',
                ],
            ])
            ->add('agreeTerms', CheckboxType::class, [
                'mapped'      => false,
                'label'       => 'J\'accepte les CGU',
                'constraints' => [
                    new IsTrue(
                        [
                            'message' => 'Vous devez accepter les CGU.',
                        ]
                    ),
                ],
            ])
            ->add('submit', SubmitType::class, [
                'label' => 'S\'enregistrer',
            ]);
    }
}
